@@ -10,7 +10,7 @@ from .models import Group, Role
 
 class PermissionsAdmin(admin.ModelAdmin):
     model = Permission
-    list_display = ['id', 'name','content_type','codename','label']
+    list_display = ['id', 'name','content_type','codename','label','sub_label']
 
 admin.site.register(Permission,PermissionsAdmin)
 
