@@ -56,4 +56,14 @@ if not hasattr(Permission, 'label'):
     sub_label.contribute_to_class(Permission, 'sub_label')
     
     
-    
\ No newline at end of file
+    
+    
+    
+
+
+class AbstractDateFieldMix(models.Model):
+    created_date              = models.DateTimeField(_('created_date'), auto_now_add=True, editable=False, blank=True, null=True)
+    modified_date             = models.DateTimeField(_('modified_date'), auto_now=True, editable=False, blank=True, null=True)
+
+    class Meta:
+        abstract = True
\ No newline at end of file
